class Person
    attr_accessor :id, :git
  
    def initialize(args = {})
      @id = args[:id] || nil
      @git = args[:git]
      validate
    end
  
    def set_contacts(phone: nil, telegram: nil, email: nil)
      @phone = phone
      raise ArgumentError, "Invalid phone number format: #{@phone}" if @phone && !self.class.valid_phone_number?(@phone)
  
      @telegram = telegram
      raise ArgumentError, "Invalid telegram format: #{@telegram}" if @telegram && !self.class.valid_telegram?(@telegram)
  
      @email = email
      raise ArgumentError, "Invalid email format: #{@email}" if @email && !self.class.valid_email?(@email)
    end
  
    def self.valid_phone_number?(phone)
      phone.match?(/\A\+?[0-9]{10,15}\z/)
    end
  
    def self.valid_name?(name)
      name.match?(/\A[А-Яа-яЁёA-Za-z\-]+\z/)
    end
  
    def self.valid_telegram?(telegram)
      telegram.nil? || telegram.match?(/\A@[A-Za-z0-9_]{5,32}\z/)
    end
  
    def self.valid_email?(email)
      email.nil? || email.match?(/\A[^@\s]+@[^@\s]+\.[^@\s]+\z/)
    end
  
    def self.valid_git?(git)
      git.nil? || git.match?(/\Ahttps:\/\/github\.com\/[A-Za-z0-9_\-]+\z/)
    end
  
    def git_present?
      !@git.nil? && !@git.empty?
    end
  
    def contact_present?
      !(@phone.nil? || @phone.empty?) || !(@telegram.nil? || @telegram.empty?) || !(@email.nil? || @email.empty?)
    end
  
    def validate
      raise ArgumentError, "Git link is required" unless git_present?
      raise ArgumentError, "At least one contact (phone, telegram, or email) is required" unless contact_present?
    end
  
    def contact_info
      return "Phone: #{@phone}" if @phone
      return "Telegram: #{@telegram}" if @telegram
      return "Email: #{@email}" if @email
      'No contact available'
    end
  
    private
  
    attr_reader :phone, :telegram, :email
    attr_writer :phone, :telegram, :email
end